TokenService class
Service to fetch LiveKit authentication tokens from your backend
Your backend (Next.js API route) must return: { "serverUrl": "...", "roomName": "...", "participantName": "...", "participantToken": "..." }
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tokenEndpoint → String
-
final
Methods
-
fetchConnectionDetails(
{required String roomName, required String participantName, String? botId, String? promptId, String? userId = "+919526019424", String language = 'en', String theme = 'dark'}) → Future< ConnectionDetails> - Fetch connection details from your backend
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited